pub struct CoherentView<'a, T: ?Sized> { /* private fields */ }Expand description
View type for Coherent.
This is same as SysMem but with additional information that allows handing out a DMA handle.
Implementations
Sourceimpl<'a, T: ?Sized> CoherentView<'a, T>
impl<'a, T: ?Sized> CoherentView<'a, T>
Sourcepub fn as_sys_mem(self) -> SysMem<'a, T>
pub fn as_sys_mem(self) -> SysMem<'a, T>
Erase the DMA handle information and obtain a SysMem view of the same memory region.
Sourcepub fn dma_handle(self) -> DmaAddress
pub fn dma_handle(self) -> DmaAddress
Returns a DMA handle which may be given to the device as the DMA address base of the region.
Sourcepub unsafe fn as_ref(self) -> &'a T
pub unsafe fn as_ref(self) -> &'a T
Returns a reference to the data in the region.
Safety
- Callers must ensure that the device does not read/write to/from memory while the returned reference is live.
- Callers must ensure that this call does not race with a write (including call to
as_mut) to the same region while the returned reference is live.
Sourcepub unsafe fn as_mut(self) -> &'a mut T
pub unsafe fn as_mut(self) -> &'a mut T
Returns a mutable reference to the data in the region.
Safety
- Callers must ensure that the device does not read/write to/from memory while the returned reference is live.
- Callers must ensure that this call does not race with a read (including call to
as_ref) or write (including call toas_mut) to the same region while the returned reference is live.